@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Converter;
 # ABSTRACT: Classe de base pour convertir les notices
-$Koha::Contrib::Sudoc::Converter::VERSION = '2.16';
+$Koha::Contrib::Sudoc::Converter::VERSION = '2.18';
 use Moose;
 use Modern::Perl;
 
@@ -135,14 +135,7 @@ sub itemize {
 
 
 sub _key_dedup {
-    my $field = shift;
-    my $key;
-    for ( @{$field->subf} ) {
-        my ($letter, $value) = @$_;
-        next unless $letter =~ /[a-z]/;
-        $key .= $value;
-    }
-    return $key;
+    join('', map { lc $_->[1] } grep { $_->[0] =~ /[a-z]/; } @{shift->subf});
 }
 
 
@@ -206,7 +199,7 @@ Koha::Contrib::Sudoc::Converter - Classe de base pour convertir les notices
 
 =head1 VERSION
 
-version 2.16
+version 2.18
 
 =head1 DESCRIPTION
 
@@ -259,7 +252,7 @@ La notice doit-elle être passée ? Par défaut, on garde toute notice.
 Méthode appelée après C<skip> pour un enregistrement SUDOC entrant, que ce
 soit un doublon ou une nouvelle notice. Initialisation du hash item.
 Suppression de la notice entrante des champs définis dans C<sudoc.conf> :
-C<biblio-proteger>
+C<biblio-exclure>
 
 =head2 authoritize
 
@@ -293,7 +286,7 @@ opération est faite après la fusion (éventuelle) de notices.
 =head2 framework
 
 Le framework auquel affecter la notice biblio. Valeur par défaut prise dans
-C<sudoc.conf>.  Peut-être surchargé pour attribuer un framework différent en
+C<sudoc.conf>.  Peut-être surchargée pour attribuer un framework différent en
 fonction du type de doc ou de tout autre critère.
 
 =head1 AUTHOR
@@ -302,7 +295,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Fréderic Demians.
+This software is Copyright (c) 2016 by Fréderic Demians.
 
 This is free software, licensed under:
 
