@@ -1,11 +1,12 @@
 package Koha::Contrib::Sudoc::Loader::Biblios;
 # ABSTRACT: Chargeur de notices biblio
-$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.16';
+$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.18';
 use Moose;
 
 extends 'Koha::Contrib::Sudoc::Loader';
 
 use Modern::Perl;
+use utf8;
 use YAML;
 use C4::Biblio;
 use C4::Items;
@@ -75,17 +76,18 @@ sub handle_record {
         my $rcr_hash = $self->sudoc->c->{rcr};
         for my $field ( $record->field('035') ) {
             my $rcr = $field->subfield('5');
-            next unless $rcr && $rcr_hash->{$rcr};
+            next unless $rcr;
+            next unless my $branch = $rcr_hash->{$rcr};
             next unless $biblionumber = $field->subfield('a');
             ($framework, $koha_record) =
                 $self->sudoc->koha->get_biblio( $biblionumber );
             if ($koha_record) {
                 $self->log->notice(
                   "  Fusion de la notice Koha $biblionumber trouvée en 035\$a " .
-                  "pour le RCR $rcr\n" );
+                  "pour le RCR $rcr ($branch)\n" );
                 last;
             }
-        } 
+        }
     }
 
     # Les doublons SUDOC. Il n'y a qu'un seul cas où on peut en faire
@@ -151,7 +153,6 @@ sub handle_record {
     $self->log->debug("\n");
 }
 
-
 1;
 
 __END__
@@ -166,7 +167,7 @@ Koha::Contrib::Sudoc::Loader::Biblios - Chargeur de notices biblio
 
 =head1 VERSION
 
-version 2.16
+version 2.18
 
 =head1 AUTHOR
 
@@ -174,7 +175,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Fréderic Demians.
+This software is Copyright (c) 2016 by Fréderic Demians.
 
 This is free software, licensed under:
 
